==> func_adl_servicex_xaodr21-2.1.2.21.2.283-py3-none-any.whl: func_adl_servicex_xaodr21/xAOD/trackmeasurementvalidation_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr21

_method_map = {
    'rdoIdentifierList': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'rdoIdentifierList',
        'return_type_element': 'unsigned long',
        'return_type_collection': 'const vector<unsigned long>',
    },
    'localX': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localX',
        'return_type': 'float',
    },
    'localY': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localY',
        'return_type': 'float',
    },
    'localXError': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localXError',
        'return_type': 'float',
    },
    'localYError': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localYError',
        'return_type': 'float',
    },
    'localXYCorrelation': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localXYCorrelation',
        'return_type': 'float',
    },
    'globalX': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'globalX',
        'return_type': 'float',
    },
    'globalY': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'globalY',
        'return_type': 'float',
    },
    'globalZ': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'globalZ',
        'return_type': 'float',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking/versions/TrackMeasurementValidation_v1.h',
            'body_includes': ["xAODTracking/versions/TrackMeasurementValidation_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking',
            'link_libraries': ["xAODTracking"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TrackMeasurementValidation_v1:
    "A class"


    def rdoIdentifierList(self) -> func_adl_servicex_xaodr21.vector_int_.vector_int_:
        "A method"
        ...

    def localX(self) -> float:
        "A method"
        ...

    def localY(self) -> float:
        "A method"
        ...

    def localXError(self) -> float:
        "A method"
        ...

    def localYError(self) -> float:
        "A method"
        ...

    def localXYCorrelation(self) -> float:
        "A method"
        ...

    def globalX(self) -> float:
        "A method"
        ...

    def globalY(self) -> float:
        "A method"
        ...

    def globalZ(self) -> float:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[func_adl_servicex_xaodr21.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[func_adl_servicex_xaodr21.str.str]:
        "A method"
        ...

==> func_adl_servicex_xaodr21-2.2.0.21.2.283-py3-none-any.whl: func_adl_servicex_xaodr21/xAOD/trackmeasurementvalidation_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr21

_method_map = {
    'identifier': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'identifier',
        'return_type': 'uint64_t',
    },
    'rdoIdentifierList': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'rdoIdentifierList',
        'return_type_element': 'unsigned long',
        'return_type_collection': 'const vector<unsigned long>',
    },
    'localX': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localX',
        'return_type': 'float',
    },
    'localY': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localY',
        'return_type': 'float',
    },
    'localXError': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localXError',
        'return_type': 'float',
    },
    'localYError': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localYError',
        'return_type': 'float',
    },
    'localXYCorrelation': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'localXYCorrelation',
        'return_type': 'float',
    },
    'globalX': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'globalX',
        'return_type': 'float',
    },
    'globalY': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'globalY',
        'return_type': 'float',
    },
    'globalZ': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'globalZ',
        'return_type': 'float',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'index',
        'return_type': 'unsigned int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TrackMeasurementValidation_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking/versions/TrackMeasurementValidation_v1.h',
            'body_includes': ["xAODTracking/versions/TrackMeasurementValidation_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTracking',
            'link_libraries': ["xAODTracking"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TrackMeasurementValidation_v1:
    "A class"


    def identifier(self) -> int:
        "A method"
        ...

    def rdoIdentifierList(self) -> func_adl_servicex_xaodr21.vector_int_.vector_int_:
        "A method"
        ...

    def localX(self) -> float:
        "A method"
        ...

    def localY(self) -> float:
        "A method"
        ...

    def localXError(self) -> float:
        "A method"
        ...

    def localYError(self) -> float:
        "A method"
        ...

    def localXYCorrelation(self) -> float:
        "A method"
        ...

    def globalX(self) -> float:
        "A method"
        ...

    def globalY(self) -> float:
        "A method"
        ...

    def globalZ(self) -> float:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[func_adl_servicex_xaodr21.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[func_adl_servicex_xaodr21.str.str]:
        "A method"
        ...
